@@ -220,7 +220,7 @@ pub struct TT_OS2 {
     pub xAvgCharWidth: FT_Short,
     pub usWeightClass: FT_UShort,
     pub usWidthClass: FT_UShort,
-    pub fsType: FT_Short,
+    pub fsType: FT_UShort,
     pub ySubscriptXSize: FT_Short,
     pub ySubscriptYSize: FT_Short,
     pub ySubscriptXOffset: FT_Short,
@@ -240,6 +240,17 @@ pub struct TT_OS2 {
     pub ulUnicodeRange3: FT_ULong, /* Bits 64-95  */
     pub ulUnicodeRange4: FT_ULong, /* Bits 96-127 */
 
+    pub achVendID: [FT_Char; 4],
+
+    pub fsSelection: FT_UShort,
+    pub usFirstCharIndex: FT_UShort,
+    pub usLastCharIndex: FT_UShort,
+    pub sTypoAscender: FT_Short,
+    pub sTypoDescender: FT_Short,
+    pub sTypoLineGap: FT_Short,
+    pub usWinAscent: FT_UShort,
+    pub usWinDescent: FT_UShort,
+
     /* only version 1 tables */
 
     pub ulCodePageRange1: FT_ULong, /* Bits 0-31  */
@@ -254,6 +265,23 @@ pub struct TT_OS2 {
     pub usMaxContext: FT_UShort,
 }
 
+#[repr(C)]
+#[derive(Debug, Copy, Clone, Hash, PartialEq, Eq)]
+pub struct TT_Postscript {
+  pub formatType: FT_Fixed,
+  pub italicAngle: FT_Fixed,
+  pub underlinePosition: FT_Short,
+  pub underlineThickness: FT_Short,
+  pub isFixedPitch: FT_ULong,
+  pub minMemType42: FT_ULong,
+  pub maxMemType42: FT_ULong,
+  pub minMemType1: FT_ULong,
+  pub maxMemType1: FT_ULong,
+
+  /* Glyph names follow in the 'post' table, but we don't */
+  /* load them by default.                                */
+}
+
 #[repr(C)]
 #[derive(Debug, Copy, Clone, Hash, PartialEq, Eq)]
 pub struct FT_Span {
@@ -564,6 +592,7 @@ pub type FT_BitmapGlyph = *mut FT_BitmapGlyphRec;
 pub type FT_OutlineGlyph = *mut FT_OutlineGlyphRec;
 pub type FT_Stroker = *mut FT_StrokerRec;
 pub type TT_OS2_Internal = *mut TT_OS2;
+pub type TT_Postscript_Internal = *mut TT_Postscript;
 
 // Internal Types
 pub type FT_LibraryRec = c_void;
